/// <reference types="node" />
import { AxiosInstance } from 'axios';
import { SDK, LoginOptions } from '@ringcentral/sdk';
import { EventEmitter } from 'events';
import { Options, Token, Config, Data } from './types';
export declare class HTTPError extends Error {
    status: number;
    statusText: string;
    data: Data;
    config: Config;
    constructor(status: number, statusText: string, data: Data, config: Config);
}
declare class RingCentralEngageVoice extends EventEmitter {
    clientId: string;
    server: string;
    clientSecret: string;
    rcServer: string;
    apiPrefix: string;
    redirectUri: string | undefined;
    _axios: AxiosInstance;
    _token: Token | undefined;
    isLegacy: Boolean;
    rc: SDK;
    static LEGACY_SERVERS: string[];
    static SERVER: string;
    static RINGCENTRAL_SERVER: string;
    constructor({ clientId, clientSecret, server, rcServer, apiPrefix }: Options);
    token(_token: Token): Token | undefined;
    refresh(): Promise<void>;
    isLegacyServer(server: string): boolean;
    request(config: Config): Promise<import("axios").AxiosResponse<any>>;
    authorize(options: LoginOptions): Promise<void>;
    legacyAuthorize(options: LoginOptions): Promise<void>;
    getLegacyToken({ username, password }: LoginOptions): Promise<void>;
    revokeLegacyToken(): Promise<import("axios").AxiosResponse<any>> | undefined;
    getToken(refreshToken: string | undefined): Promise<void>;
    _patchHeaders(headers?: Data): {
        'Content-Type': string;
        'X-User-Agent': string;
        'RC-User-Agent': string;
        'X-Auth-Token': string;
    } | {
        'Content-Type': string;
        'X-User-Agent': string;
        'RC-User-Agent': string;
        Authorization: string;
    };
    _bearerAuthorizationHeader(): {
        Authorization: string;
    };
    _legacyHeader(): {
        'X-Auth-Token': string;
    };
    get(url: string, config?: Config): Promise<import("axios").AxiosResponse<any>>;
    delete(url: string, config?: Config): Promise<import("axios").AxiosResponse<any>>;
    post(url: string, data?: Data | undefined, config?: Config): Promise<import("axios").AxiosResponse<any>>;
    put(url: string, data?: Data | undefined, config?: Config): Promise<import("axios").AxiosResponse<any>>;
    patch(url: string, data?: Data | undefined, config?: Config): Promise<import("axios").AxiosResponse<any>>;
}
export default RingCentralEngageVoice;
